@@ -6,8 +6,7 @@ store_class_format.auto <- function(format) {
 store_class_format_auto <- c("tar_auto", "tar_store")
 
 #' @export
-store_assert_format_setting.auto <- function(format) {
-}
+store_assert_format_setting.auto <- function(format) {}
 
 #' @export
 store_get_packages.tar_auto <- function(store) {
