@@ -35,8 +35,7 @@ store_produce_stage.tar_aws_file <- function(store, name, object, path_store) {
 }
 
 #' @export
-store_assert_format_setting.aws_file <- function(format) {
-}
+store_assert_format_setting.aws_file <- function(format) {}
 
 #' @export
 store_upload_object.tar_aws_file <- function(store, file) {
@@ -44,7 +43,8 @@ store_upload_object.tar_aws_file <- function(store, file) {
 }
 
 #' @export
-store_hash_early.tar_aws_file <- function(store, file) { # nolint
+store_hash_early.tar_aws_file <- function(store, file) {
+  # nolint
   old <- file$path
   file$path <- store_aws_file_stage(file$path)
   on.exit(file$path <- old)
@@ -53,7 +53,8 @@ store_hash_early.tar_aws_file <- function(store, file) { # nolint
 }
 
 #' @export
-store_hash_late.tar_aws_file <- function(store, file) { # nolint
+store_hash_late.tar_aws_file <- function(store, file) {
+  # nolint
 }
 
 #' @export
