@@ -81,12 +81,10 @@ target_produce_record.tar_branch <- function(target, pipeline, meta) {
 }
 
 #' @export
-target_ensure_buds.tar_branch <- function(target, pipeline, scheduler) {
-}
+target_ensure_buds.tar_branch <- function(target, pipeline, scheduler) {}
 
 #' @export
-target_restore_buds.tar_branch <- function(target, pipeline, scheduler, meta) {
-}
+target_restore_buds.tar_branch <- function(target, pipeline, scheduler, meta) {}
 
 #' @export
 target_validate.tar_branch <- function(target) {
