@@ -105,18 +105,40 @@ target_should_run.tar_builder <- function(target, meta) {
 # nolint start
 builder_should_run <- function(target, meta) {
   cue <- .subset2(target, "cue")
-  if (cue_meta_exists(cue, target, meta)) return(TRUE)
+  if (cue_meta_exists(cue, target, meta)) {
+    return(TRUE)
+  }
   row <- .subset2(meta, "get_row")(target_get_name(target))
-  if (cue_meta(cue, target, meta, row)) return(TRUE)
-  if (cue_always(cue, target, meta)) return(TRUE)
-  if (cue_never(cue, target, meta)) return(FALSE)
-  if (cue_command(cue, target, meta, row)) return(TRUE)
-  if (cue_depend(cue, target, meta, row)) return(TRUE)
-  if (cue_format(cue, target, meta, row)) return(TRUE)
-  if (cue_repository(cue, target, meta, row)) return(TRUE)
-  if (cue_iteration(cue, target, meta, row)) return(TRUE)
-  if (cue_seed(cue, target, meta, row)) return(TRUE)
-  if (cue_file(cue, target, meta, row)) return(TRUE)
+  if (cue_meta(cue, target, meta, row)) {
+    return(TRUE)
+  }
+  if (cue_always(cue, target, meta)) {
+    return(TRUE)
+  }
+  if (cue_never(cue, target, meta)) {
+    return(FALSE)
+  }
+  if (cue_command(cue, target, meta, row)) {
+    return(TRUE)
+  }
+  if (cue_depend(cue, target, meta, row)) {
+    return(TRUE)
+  }
+  if (cue_format(cue, target, meta, row)) {
+    return(TRUE)
+  }
+  if (cue_repository(cue, target, meta, row)) {
+    return(TRUE)
+  }
+  if (cue_iteration(cue, target, meta, row)) {
+    return(TRUE)
+  }
+  if (cue_seed(cue, target, meta, row)) {
+    return(TRUE)
+  }
+  if (cue_file(cue, target, meta, row)) {
+    return(TRUE)
+  }
   FALSE
 }
 # nolint end
@@ -132,7 +154,12 @@ target_needs_worker.tar_builder <- function(target) {
 }
 
 #' @export
-target_run.tar_builder <- function(target, envir, path_store) {
+target_run.tar_builder <- function(
+  target,
+  envir,
+  path_store,
+  on_worker = FALSE
+) {
   if (package_installed("autometric (>= 0.1.0)")) {
     autometric::log_phase_set(phase = target_get_name(target))
     on.exit(autometric::log_phase_reset())
@@ -150,10 +177,12 @@ target_run.tar_builder <- function(target, envir, path_store) {
     name = target_get_name(target),
     path_store = path_store
   )
+  runtime_increment_targets_run(tar_runtime)
+  target_gc(target)
   builder_update_build(target, frames_get_envir(frames))
   builder_ensure_paths(target, path_store)
-  builder_ensure_object(target, "worker")
-  builder_ensure_object(target, "none")
+  builder_ensure_object(target, "worker", on_worker)
+  builder_ensure_object(target, "none", on_worker)
   target
 }
 
@@ -176,10 +205,8 @@ target_run_worker.tar_builder <- function(
   tar_option_set(envir = envir)
   tar_runtime$store <- path_store
   tar_runtime$fun <- fun
-  runtime_increment_targets_run(tar_runtime)
-  target_gc(target)
   builder_unmarshal_subpipeline(target)
-  target_run(target, envir, path_store)
+  target_run(target, envir, path_store, on_worker = TRUE)
   builder_marshal_value(target)
   target
 }
@@ -244,7 +271,7 @@ target_conclude.tar_builder <- function(target, pipeline, scheduler, meta) {
     scheduler = scheduler,
     meta = meta
   )
-  builder_ensure_object(target, "main")
+  builder_ensure_object(target, "main", on_worker = FALSE)
   builder_ensure_correct_hash(target)
   builder_handle_warnings(target, scheduler)
   switch(
@@ -262,7 +289,9 @@ builder_completed <- function(target, pipeline, scheduler, meta) {
   meta$insert_record(target_produce_record(target, pipeline, meta))
   target_patternview_meta(target, pipeline, meta)
   pipeline_set_target(pipeline, target)
-  pipeline_register_loaded(pipeline, target_get_name(target))
+  if (!is.null(target$value)) {
+    pipeline_register_loaded(pipeline, target_get_name(target))
+  }
   scheduler$progress$register_completed(target)
   scheduler$reporter$report_completed(target, scheduler$progress)
 }
@@ -301,11 +330,6 @@ target_debug.tar_builder <- function(target) {
   }
 }
 
-#' @export
-target_sync_file_meta.tar_builder <- function(target, meta) {
-  store_sync_file_meta(target$store, target, meta)
-}
-
 #' @export
 target_get_packages.tar_builder <- function(target) {
   packages_command <- target$command$packages
@@ -347,11 +371,11 @@ builder_unmarshal_subpipeline <- function(target) {
   }
   patterns <- fltr(
     pipeline_get_names(subpipeline),
-    ~inherits(pipeline_get_target(subpipeline, .x), "tar_pattern")
+    ~ inherits(pipeline_get_target(subpipeline, .x), "tar_pattern")
   )
   map(
     setdiff(patterns, target$settings$dimensions),
-    ~target_ensure_value(pipeline_get_target(subpipeline, .x), subpipeline)
+    ~ target_ensure_value(pipeline_get_target(subpipeline, .x), subpipeline)
   )
 }
 
@@ -419,6 +443,7 @@ builder_save_workspace <- function(target, pipeline, scheduler, meta) {
     path_store = meta$store
   )
   scheduler$reporter$report_workspace(target)
+  meta$database$upload_workspace(target, meta, scheduler$reporter)
 }
 
 builder_record_error_meta <- function(target, pipeline, meta) {
@@ -433,7 +458,13 @@ builder_update_build <- function(target, envir) {
   object <- build$object
   object <- tryCatch(
     builder_resolve_object(target, build),
-    error = function(error) builder_error_internal(target, error, "_build_")
+    error = function(error) {
+      builder_error_internal(
+        target,
+        error,
+        "Error resolving stored output:"
+      )
+    }
   )
   if (!identical(target$settings$storage, "none")) {
     target$value <- value_init(object, target$settings$iteration)
@@ -461,7 +492,13 @@ builder_ensure_paths <- function(target, path_store) {
   if (builder_expect_storage(target)) {
     tryCatch(
       builder_update_paths(target, path_store),
-      error = function(error) builder_error_internal(target, error, "_paths_")
+      error = function(error) {
+        builder_error_internal(
+          target,
+          error,
+          "Error resolving output location:"
+        )
+      }
     )
   }
 }
@@ -485,17 +522,14 @@ builder_update_paths <- function(target, path_store) {
   store_hash_early(target$store, target$file)
 }
 
-builder_unload_value <- function(target) {
-  settings <- target$settings
-  clear <- identical(settings$deployment, "worker") &&
-    identical(settings$storage, "worker")
-  if (clear) {
+builder_unload_value <- function(target, on_worker) {
+  if (on_worker && identical(target$settings$storage, "worker")) {
     store_unload(store = target$store, target = target)
   }
 }
 
-builder_update_object <- function(target) {
-  on.exit(builder_unload_value(target))
+builder_update_object <- function(target, on_worker = FALSE) {
+  on.exit(builder_unload_value(target, on_worker))
   file_validate_path(target$file$path)
   if (!identical(target$settings$storage, "none")) {
     withCallingHandlers(
@@ -522,12 +556,18 @@ builder_expect_storage <- function(target) {
   !metrics_terminated_early(target$metrics) && !error_null
 }
 
-builder_ensure_object <- function(target, storage) {
+builder_ensure_object <- function(target, storage, on_worker) {
   context <- identical(target$settings$storage, storage)
   if (context && builder_expect_storage(target)) {
     tryCatch(
-      builder_update_object(target),
-      error = function(error) builder_error_internal(target, error, "_store_")
+      builder_update_object(target, on_worker),
+      error = function(error) {
+        builder_error_internal(
+          target,
+          error,
+          "Error storing output:"
+        )
+      }
     )
   }
 }
@@ -545,7 +585,13 @@ builder_ensure_correct_hash <- function(target) {
   if (!metrics_terminated_early(target$metrics)) {
     tryCatch(
       builder_wait_correct_hash(target),
-      error = function(error) builder_error_internal(target, error, "_hash_")
+      error = function(error) {
+        builder_error_internal(
+          target,
+          error,
+          "Error hashing output:"
+        )
+      }
     )
   }
 }
