@@ -128,7 +128,7 @@ database_class <- R6::R6Class(
       names(list_column_mode_list) <- list_columns
       out <- map(
         rows,
-        ~database_repair_list_columns(
+        ~ database_repair_list_columns(
           as.list(get_row(.x)),
           list_columns,
           list_column_mode_list
@@ -378,7 +378,7 @@ database_class <- R6::R6Class(
       out
     },
     produce_mock_data = function() {
-      out <- as_data_frame(map(self$header, ~character(0)))
+      out <- as_data_frame(map(self$header, ~ character(0)))
       colnames(out) <- self$header
       out
     },
@@ -528,18 +528,28 @@ database_class <- R6::R6Class(
         return()
       }
       line <- readLines(self$path, n = 1L)
-      header <- strsplit(line, split = database_sep_outer, fixed = TRUE)[[1]]
+      header <- if_any(
+        length(line) > 0L,
+        strsplit(line, split = database_sep_outer, fixed = TRUE)[[1]],
+        ""
+      )
       if (identical(header, self$header)) {
         return()
       }
       tar_throw_file(
-        "invalid header in ", self$path, "\n",
-        "  found:    ", paste(header, collapse = database_sep_outer), "\n",
-        "  expected: ", paste(self$header, collapse = database_sep_outer),
-        "\nProbably because of a breaking change in the targets package. ",
-        "Before running tar_make() again, ",
-        "either delete the data store with tar_destroy() ",
-        "or downgrade the targets package to an earlier version."
+        "invalid header in the {targets} database file ",
+        self$path,
+        "\n",
+        "  found:    ",
+        paste(header, collapse = database_sep_outer),
+        "\n",
+        "  expected: ",
+        paste(self$header, collapse = database_sep_outer),
+        "\nEither there was a breaking change in the {targets} package ",
+        "or the metadata file was corrupted somehow. ",
+        "Before running tar_make() again, either delete the aforementioned ",
+        "database file, or if applicable, ",
+        "downgrade the {targets} package to an earlier version."
       )
     },
     validate = function() {
