@@ -303,9 +303,7 @@ options_class <- R6::R6Class(
       self$repository %|||% "local"
     },
     get_repository_meta = function() {
-      default <- self$repository_meta %|||%
-        if_any(is_repository_cas(self$repository), "local", self$repository)
-      default %|||% "local"
+      self$repository_meta %|||% "local"
     },
     get_iteration = function() {
       self$iteration %|||% "vector"
@@ -317,7 +315,7 @@ options_class <- R6::R6Class(
       self$memory %|||% "auto"
     },
     get_garbage_collection = function() {
-      self$garbage_collection %|||% 1000L
+      self$garbage_collection %|||% 0L
     },
     get_deployment = function() {
       self$deployment %|||% "worker"
@@ -332,10 +330,10 @@ options_class <- R6::R6Class(
       self$resources %|||% list()
     },
     get_storage = function() {
-      self$storage %|||% "main"
+      self$storage %|||% "worker"
     },
     get_retrieval = function() {
-      self$retrieval %|||% "main"
+      self$retrieval %|||% "auto"
     },
     get_cue = function() {
       self$cue %|||% tar_cue()
@@ -537,6 +535,7 @@ options_class <- R6::R6Class(
       tar_assert_scalar(priority)
       tar_assert_ge(priority, 0)
       tar_assert_le(priority, 1)
+      deprecate_priority(priority)
     },
     validate_backoff = function(backoff) {
       tar_assert_inherits(backoff, class = "tar_backoff")
@@ -549,7 +548,7 @@ options_class <- R6::R6Class(
       tar_assert_flag(storage, c("main", "worker", "none"))
     },
     validate_retrieval = function(retrieval) {
-      tar_assert_flag(retrieval, c("main", "worker", "none"))
+      tar_assert_flag(retrieval, c("auto", "main", "worker", "none"))
     },
     validate_cue = function(cue) {
       cue_validate(cue)
@@ -633,3 +632,18 @@ deprecate_error_workspace <- function(error) {
     )
   }
 }
+
+deprecate_priority <- function(priority) {
+  if (priority > 0) {
+    tar_warn_deprecate(
+      "Effective 2025-04-08 (targets version 1.10.1.9013), ",
+      "the `priority` argument is deprecated in tar_target(), ",
+      "tar_target_raw(), and tar_option_set(). ",
+      "The targets package has moved to a more efficient scheduling ",
+      "algorithm (https://github.com/ropensci/targets/issues/1458) ",
+      "which does not support custom user-specified priorities. ",
+      "User-specified priorities no longer have a reliable ",
+      "effect on execution order."
+    )
+  }
+}
