@@ -6,6 +6,7 @@ runtime_new <- function(
   store = NULL,
   working_directory = NULL,
   fun = NULL,
+  active = NULL,
   gcp_auth = NULL,
   file_exist = NULL,
   file_info = NULL,
@@ -16,7 +17,8 @@ runtime_new <- function(
   trust_timestamps_store = NULL,
   number_targets_run = NULL,
   installed_packages = NULL,
-  meta = NULL
+  meta = NULL,
+  progress_bar = NULL
 ) {
   out <- new.env(parent = emptyenv(), hash = FALSE)
   out$target <- target
@@ -26,6 +28,7 @@ runtime_new <- function(
   out$store <- store
   out$working_directory <- working_directory
   out$fun <- fun
+  out$active <- active
   out$gcp_auth <- gcp_auth
   out$file_exist <- file_exist
   out$file_info <- file_info
@@ -37,6 +40,7 @@ runtime_new <- function(
   out$number_targets_run <- number_targets_run
   out$installed_packages <- installed_packages
   out$meta <- meta
+  out$progress_bar <- progress_bar
   out
 }
 
@@ -78,6 +82,10 @@ runtime_validate_basics <- function(x) {
     tar_assert_chr(x$fun)
     tar_assert_nzchar(x$fun)
   }
+  if (!is.null(x$active)) {
+    tar_assert_lgl(x$active)
+    tar_assert_scalar(x$active)
+  }
   if (!is.null(x$number_targets_run)) {
     tar_assert_scalar(x$number_targets_run)
     tar_assert_int(x$number_targets_run)
@@ -119,19 +127,36 @@ runtime_validate_extras <- function(x) {
   if (!is.null(x$meta)) {
     tar_assert_envir(x$meta)
   }
+  if (!is.null(x$progress_bar)) {
+    tar_assert_lgl(x$progress_bar)
+    tar_assert_scalar(x$progress_bar)
+    tar_assert_none_na(x$progress_bar)
+  }
 }
 
-runtime_set_file_info <- function(runtime, store) {
-  runtime$trust_timestamps_store <- trust_timestamps(store)
-  objects <- list.files(
-    path = path_objects_dir(store),
-    all.files = TRUE,
-    full.names = TRUE,
-    no.. = TRUE
+runtime_set_file_info <- function(runtime, store, names) {
+  bar <- cli_local_progress_bar_init(
+    label = paste(
+      "querying",
+      length(names),
+      "local files in",
+      path_objects_dir(store)
+    )
   )
+  on.exit(cli_local_progress_bar_destroy(bar = bar))
+  runtime$trust_timestamps_store <- trust_timestamps(store)
   runtime$file_systems <- runtime_file_systems()
-  file_info <- as.list(file_info(objects, trust_timestamps = FALSE))
-  file_info <- file_info[c("path", "size", "mtime_numeric")]
+  info <- file_info(
+    file.path(path_objects_dir(store), names),
+    trust_timestamps = FALSE
+  )
+  info <- as.list(info)
+  keep <- !is.na(info$size)
+  info$path <- info$path[keep]
+  info$size <- info$size[keep]
+  info$mtime_numeric <- info$mtime_numeric[keep]
+  objects <- info$path
+  file_info <- info[c("path", "size", "mtime_numeric")]
   file_info$trust_timestamps <- rep(
     runtime$trust_timestamps_store,
     length(objects)
@@ -167,8 +192,7 @@ runtime_increment_targets_run <- function(x) {
   if (is.null(count)) {
     count <- 0L
   }
-  count <- count + 1L
-  x$number_targets_run <- count
+  x$number_targets_run <- count + 1L
 }
 
 runtime_reset <- function(x) {
