@@ -227,24 +227,37 @@ target_produce_child.tar_stem <- function(target, name, index) {
 print.tar_stem <- function(x, ...) {
   cat(
     "<tar_stem>",
-    "\n  name:", target_get_name(x),
-    "\n  description:", x$settings$description,
+    "\n  name:",
+    target_get_name(x),
+    "\n  description:",
+    x$settings$description,
     "\n  command:\n   ",
     produce_lines(string_sub_expression(x$command$string)),
-    "\n  format:", x$settings$format,
-    "\n  repository:", x$settings$repository,
-    "\n  iteration method:", x$settings$iteration,
-    "\n  error mode:", x$settings$error,
-    "\n  memory mode:", x$settings$memory,
-    "\n  storage mode:", x$settings$storage,
-    "\n  retrieval mode:", x$settings$retrieval,
-    "\n  deployment mode:", x$settings$deployment,
-    "\n  priority:", x$settings$priority,
+    "\n  format:",
+    x$settings$format,
+    "\n  repository:",
+    x$settings$repository,
+    "\n  iteration method:",
+    x$settings$iteration,
+    "\n  error mode:",
+    x$settings$error,
+    "\n  memory mode:",
+    x$settings$memory,
+    "\n  storage mode:",
+    x$settings$storage,
+    "\n  retrieval mode:",
+    x$settings$retrieval,
+    "\n  deployment mode:",
+    x$settings$deployment,
+    "\n  priority:",
+    x$settings$priority,
     "\n  resources:\n   ",
     produce_lines(paste_list(x$settings$resources)),
     "\n  cue:\n   ",
     produce_lines(paste_list(as.list(x$cue))),
-    "\n  packages:\n   ", produce_lines(x$command$packages),
-    "\n  library:\n   ", produce_lines(x$command$library)
+    "\n  packages:\n   ",
+    produce_lines(x$command$packages),
+    "\n  library:\n   ",
+    produce_lines(x$command$library)
   )
 }
