@@ -67,9 +67,12 @@ visual_class <- R6::R6Class(
       vertices <- self$network$vertices
       description <- vertices$description
       description[is.na(description)] <- ""
-      seconds <- as.character(units_seconds(vertices$seconds))
-      bytes <- as.character(units_bytes(vertices$bytes))
-      branches <- as.character(units_branches(vertices$branches))
+      seconds <- prettyunits::pretty_sec(vertices$seconds)
+      seconds[is.na(vertices$seconds)] <- ""
+      bytes <- prettyunits::pretty_bytes(vertices$bytes)
+      bytes[is.na(vertices$bytes)] <- ""
+      branches <- paste(vertices$branches, "branches")
+      branches[is.na(vertices$branches)] <- ""
       if (!is.null(self$label_width)) {
         n <- self$label_width
         description <- truncate_character(description, n)
@@ -100,6 +103,16 @@ visual_class <- R6::R6Class(
       vertices <- self$network$vertices
       vertices$color <- self$produce_fills(vertices$status)
       self$network$vertices <- vertices
+      colors <- vertices[, c("name", "color")]
+      colors$to <- colors$name
+      colors$name <- NULL
+      self$network$edges <- merge(
+        x = self$network$edges,
+        y = colors,
+        by = "to",
+        all.x = TRUE,
+        all.y = FALSE
+      )[, c("from", "to", "color")]
     },
     update_legend = function() {
       self$legend <- self$produce_legend()
