@@ -49,7 +49,7 @@ tar_config_get <- function(
 
 tar_config_is_multi_project <- function(yaml, config) {
   yaml <- yaml[!map_lgl(yaml, is.null)]
-  out <- !length(yaml) || any(map_lgl(yaml, ~is.list(.x)))
+  out <- !length(yaml) || any(map_lgl(yaml, ~ is.list(.x)))
   if (!out && any(file.exists(config))) {
     msg <- paste(
       "As of targets version 0.7.9001 (September 2021),",
@@ -136,7 +136,7 @@ tar_config_get_convert <- function(name, value) {
 
 reporter_default <- function() {
   if_any(
-    isTRUE(getOption("knitr.in.progress")),
+    isTRUE(getOption("knitr.in.progress")) || !interactive(),
     "terse",
     "balanced"
   )
