@@ -65,7 +65,10 @@
 tar_load <- function(
   names,
   branches = NULL,
-  meta = targets::tar_meta(targets_only = TRUE, store = store),
+  meta = targets::tar_meta(
+    store = store,
+    fields = -tidyselect::any_of("time")
+  ),
   strict = TRUE,
   silent = FALSE,
   envir = parent.frame(),
