@@ -25,7 +25,10 @@
 #' }
 tar_load_everything <- function(
   branches = NULL,
-  meta = tar_meta(targets_only = TRUE, store = store),
+  meta = targets::tar_meta(
+    store = store,
+    fields = -tidyselect::any_of("time")
+  ),
   strict = TRUE,
   silent = FALSE,
   envir = parent.frame(),
