@@ -3,7 +3,10 @@
 tar_read_raw <- function(
   name,
   branches = NULL,
-  meta = tar_meta(store = store),
+  meta = targets::tar_meta(
+    store = store,
+    fields = -tidyselect::any_of("time")
+  ),
   store = targets::tar_config_get("store")
 ) {
   tar_assert_allow_meta("tar_read_raw", store)
@@ -21,7 +24,7 @@ tar_read_inner <- function(name, branches, meta, path_store) {
   if (!any(index)) {
     tar_throw_validate("target ", name, " not found")
   }
-  row <- meta[max(which(index)),, drop = FALSE] # nolint
+  row <- meta[max(which(index)), , drop = FALSE] # nolint
   record <- record_from_row(row = row, path_store = path_store)
   if_any(
     record$type %in% c("stem", "branch"),
@@ -31,7 +34,9 @@ tar_read_inner <- function(name, branches, meta, path_store) {
 }
 
 read_builder <- function(record) {
-  store_read_object(record_bootstrap_store(record))
+  store <- record_bootstrap_store(record)
+  file <- record_bootstrap_file(record)
+  store_read_object(store, file)
 }
 
 read_pattern <- function(name, record, meta, branches, path_store) {
@@ -46,11 +51,11 @@ read_pattern <- function(name, record, meta, branches, path_store) {
       paste(diff, collapse = ", ")
     )
   }
-  meta <- meta[meta$name %in% names,, drop = FALSE] # nolint
+  meta <- meta[meta$name %in% names, , drop = FALSE] # nolint
   if (nrow(meta)) {
-    meta <- meta[match(names, meta$name),, drop = FALSE] # nolint
+    meta <- meta[match(names, meta$name), , drop = FALSE] # nolint
   }
-  records <- map_rows(meta, ~record_from_row(.x, path_store = path_store))
+  records <- map_rows(meta, ~ record_from_row(.x, path_store = path_store))
   objects <- lapply(records, read_builder)
   names(objects) <- names
   value <- value_init(iteration = record$iteration)
