@@ -168,15 +168,17 @@ cli_local_progress_bar_init <- function(label, total = NA_integer_) {
 cli_local_progress_bar_update <- function(bar, index = 1L, force = FALSE) {
   envir <- parent.frame()
   force(envir)
-  print_progress <- cli_use_local_progress_bar() && (
-    force ||
+  total <- .subset2(bar, "total")
+  # nolint start
+  print_progress <- cli_use_local_progress_bar() &&
+    (force ||
       (index == 1L) ||
-      !(index %% max(1L, as.integer(.subset2(bar, "total") / 10)))
-  )
+      !(index %% max(1L, as.integer(total / 10))))
+  # nolint end
   if (print_progress) {
     cli::cli_progress_update(
       set = index,
-      force = TRUE,
+      force = is.na(total),
       id = bar$id,
       .envir = bar$envir
     )
