@@ -162,11 +162,14 @@ trust_timestamps <- function(path) {
       file_systems <- runtime_file_systems()
       tar_runtime$file_systems <- file_systems
     }
-    try({
-      mounts <- ps::ps_fs_mount_point(existing)
-      types <- as.character(file_systems[mounts])
-      trust[exists] <- !(types %in% unsafe)
-    }, silent = TRUE)
+    try(
+      {
+        mounts <- ps::ps_fs_mount_point(existing)
+        types <- as.character(file_systems[mounts])
+        trust[exists] <- !(types %in% unsafe)
+      },
+      silent = TRUE
+    )
   }
   trust
 }
