@@ -9,14 +9,17 @@ tar_test("gcp_file format file gets stored", {
   googleCloudStorageR::gcs_create_bucket(bucket_name, projectId = project)
   on.exit(gcp_gcs_delete_bucket(bucket_name))
   expr <- quote({
-    tar_option_set(resources = tar_resources(
-      gcp = tar_resources_gcp(bucket = !!bucket_name, prefix = "_targets")
-    ))
+    tar_option_set(
+      resources = tar_resources(
+        gcp = tar_resources_gcp(bucket = !!bucket_name, prefix = "_targets")
+      )
+    )
     evalq(
       write_local_file <- function(lines) {
         writeLines(lines, "example_gcp_file.txt")
         "example_gcp_file.txt"
-      }, envir = tar_option_get("envir")
+      },
+      envir = tar_option_get("envir")
     )
     list(
       tar_target(
@@ -84,7 +87,8 @@ tar_test("gcp_file format invalidation", {
         write_local_file <- function(lines) {
           writeLines(lines, "example_gcp_file.txt")
           "example_gcp_file.txt"
-        }, envir = tar_option_get("envir")
+        },
+        envir = tar_option_get("envir")
       )
       list(
         tar_target(
@@ -118,7 +122,8 @@ tar_test("gcp_file format invalidation", {
         write_local_file <- function(lines) {
           writeLines(lines, "example_gcp_file.txt")
           "example_gcp_file.txt"
-        }, envir = tar_option_get("envir")
+        },
+        envir = tar_option_get("envir")
       )
       list(
         tar_target(
@@ -152,14 +157,17 @@ tar_test("gcp_file format with a custom data store", {
   googleCloudStorageR::gcs_create_bucket(bucket_name, projectId = project)
   on.exit(gcp_gcs_delete_bucket(bucket_name))
   expr <- quote({
-    tar_option_set(resources = tar_resources(
-      gcp = tar_resources_gcp(bucket = !!bucket_name, prefix = "_targets")
-    ))
+    tar_option_set(
+      resources = tar_resources(
+        gcp = tar_resources_gcp(bucket = !!bucket_name, prefix = "_targets")
+      )
+    )
     evalq(
       write_local_file <- function(lines) {
         writeLines(lines, "example_gcp_file.txt")
         "example_gcp_file.txt"
-      }, envir = tar_option_get("envir")
+      },
+      envir = tar_option_get("envir")
     )
     list(
       tar_target(
