@@ -40,14 +40,17 @@ tar_test("nontrivial common data with multiprocess", {
   tar_script({
     options(clustermq.scheduler = "multiprocess")
     envir <- new.env(parent = globalenv())
-    evalq({
-      f <- function(x) {
-        g(x) + 1L
-      }
-      g <- function(x) {
-        x + 1L
-      }
-    }, envir = envir)
+    evalq(
+      {
+        f <- function(x) {
+          g(x) + 1L
+        }
+        g <- function(x) {
+          x + 1L
+        }
+      },
+      envir = envir
+    )
     tar_option_set(envir = envir)
     list(
       tar_target(x, 1),
