@@ -1,3 +1,16 @@
+# Targets x1 and x2 should run on parallel workers.
+# Run in a basic terminal, monitor with htop -d 1, and filter on R.home().
+library(targets)
+tar_script({
+  tar_option_set(controller = crew::crew_controller_local(workers = 2L))
+  list(
+    tar_target(x1, list(Sys.sleep(5), 1)),
+    tar_target(x2, list(Sys.sleep(5), 2))
+  )
+})
+tar_make()
+tar_destroy()
+
 # This interactive test checks parallel efficiency.
 # We should not have to wait for all the `x2` branches to finish
 # before we move on to `x3`-`x6` branches downstream of the
@@ -5,7 +18,7 @@
 library(targets)
 library(testthat)
 tar_script({
-  options(clustermq.scheduler = "multiprocess")
+  tar_option_set(controller = crew::crew_controller_local(workers = 3L))
   list(
     tar_target(x1, c(0, 0, 5)),
     tar_target(x2, Sys.sleep(x1), pattern = map(x1)),
@@ -15,22 +28,7 @@ tar_script({
     tar_target(x6, x5, pattern = map(x5))
   )
 })
-tar_make_clustermq(workers = 3L, reporter = "timestamp")
-tar_destroy()
-
-# All but 1 worker should quit while x4 is running.
-# Run in a basic terminal, monitor with htop -d 1, and filter on R.home().
-library(targets)
-tar_script({
-  options(clustermq.scheduler = "multiprocess")
-  list(
-    tar_target(x1, Sys.sleep(1)),
-    tar_target(x2, list(Sys.sleep(1), x1)),
-    tar_target(x3, list(Sys.sleep(0), x2)),
-    tar_target(x4, list(Sys.sleep(5), x3))
-  )
-})
-tar_make_clustermq(workers = 4L, reporter = "timestamp", callr_function = NULL)
+tar_make(reporter = "timestamp")
 tar_destroy()
 
 # All but 1 worker should quit while the last x4 branch is running.
@@ -93,16 +91,16 @@ unlink("_targets.R")
 # error = "abridge" should keep current targets going.
 # Workers should clean up.
 tar_script({
-  options(clustermq.scheduler = "multiprocess")
+  tar_option_set(controller = crew::crew_controller_local(workers = 3L))
   error_middle <- function() {
-    Sys.sleep(4)
+    Sys.sleep(2)
     stop("time up")
   }
   just_sleep_short <- function() {
-    Sys.sleep(8)
+    Sys.sleep(4)
   }
   just_sleep_long <- function() {
-    Sys.sleep(12)
+    Sys.sleep(5)
   }
   list(
     tar_target(w, error_middle(), error = "abridge"),
@@ -111,7 +109,7 @@ tar_script({
     tar_target(z, list(w, x, y))
   )
 })
-tar_make_clustermq(workers = 3)
+tar_make()
 out <- tar_progress()
 expect_equal(nrow(out), 3L)
 expect_equal(out$progress[out$name == "w"], "errored")
