@@ -63,12 +63,15 @@ mermaid(vis$visual)
 # Should show everything at h and downstream outdated
 # and everything else up to date.
 envir <- new.env(parent = baseenv())
-evalq({
-  f <- function(x) g(x) + h
-  g <- function(x) i
-  h <- 1
-  i <- 1
-}, envir = envir)
+evalq(
+  {
+    f <- function(x) g(x) + h
+    g <- function(x) i
+    h <- 1
+    i <- 1
+  },
+  envir = envir
+)
 tar_option_set(envir = envir)
 pipeline <- pipeline_init(
   list(
