@@ -1,12 +1,15 @@
 tar_test("tar_branch_index()", {
   skip_cran()
-  tar_script({
-    list(
-      tar_target(x, seq_len(4L)),
-      tar_target(y, 2L * x, pattern = map(x)),
-      tar_target(z, y, pattern = map(y))
-    )
-  }, ask = FALSE)
+  tar_script(
+    {
+      list(
+        tar_target(x, seq_len(4L)),
+        tar_target(y, 2L * x, pattern = map(x)),
+        tar_target(z, y, pattern = map(y))
+      )
+    },
+    ask = FALSE
+  )
   tar_make(callr_function = NULL)
   names <- c(
     tar_meta(y, children)$children[[1L]][c(2L, 3L)],
@@ -17,13 +20,16 @@ tar_test("tar_branch_index()", {
 
 tar_test("bad branch names", {
   skip_cran()
-  tar_script({
-    list(
-      tar_target(x, seq_len(4L)),
-      tar_target(y, 2L * x, pattern = map(x)),
-      tar_target(z, y, pattern = map(y))
-    )
-  }, ask = FALSE)
+  tar_script(
+    {
+      list(
+        tar_target(x, seq_len(4L)),
+        tar_target(y, 2L * x, pattern = map(x)),
+        tar_target(z, y, pattern = map(y))
+      )
+    },
+    ask = FALSE
+  )
   tar_make(callr_function = NULL)
   expect_error(tar_branch_index("abc"), class = "tar_condition_validate")
   branches <- tar_meta(y, children)$children[[1L]][c(2L, 3L)]
