@@ -51,13 +51,16 @@ tar_test("custom script and store args", {
   skip_cran()
   expect_equal(tar_config_get("script"), path_script_default())
   expect_equal(tar_config_get("store"), path_store_default())
-  tar_script({
-    list(
-      tar_target(w, letters),
-      tar_target(x, w, pattern = map(w)),
-      tar_target(dynamic, x, pattern = sample(x, 10))
-    )
-  }, script = "example/script.R")
+  tar_script(
+    {
+      list(
+        tar_target(w, letters),
+        tar_target(x, w, pattern = map(w)),
+        tar_target(dynamic, x, pattern = sample(x, 10))
+      )
+    },
+    script = "example/script.R"
+  )
   try(
     tar_make(
       callr_function = NULL,
