@@ -4,7 +4,7 @@ tar_test("tar_skipped() empty", {
 })
 
 tar_test("tar_skipped() nonempty", {
-  skip_on_cran()
+  skip_cran()
   tar_script(list(tar_target(x, 1), tar_target(y, 1)))
   tar_make(callr_function = NULL)
   tar_make(callr_function = NULL)
